@@ -16,6 +16,7 @@ from IPython.display import display
 import importlib
 import warnings
 from warnings import warn
+import psutil
 
 import torch
 import torch.nn as nn
@@ -30,7 +31,6 @@ from fastcore.test import *
 from fastcore.foundation import *
 from fastcore.meta import *
 from fastcore.dispatch import *
-# from fastcore.utils import *
 
 import fastai
 from fastai.basics import *
@@ -42,20 +42,30 @@ import datetime
 device = 'cuda' if torch.cuda.is_available() else 'cpu'
 cpus = defaults.cpus
 
+def get_gpu_memory():
+    import subprocess
+    command = "nvidia-smi --query-gpu=memory.total --format=csv"
+    memory_info = subprocess.check_output(command.split()).decode('ascii').split('\n')[:-1][1:]
+    memory_values = [round(int(x.split()[0])/1024, 2) for i, x in enumerate(memory_info)]
+    return memory_values
+
+def get_ram_memory():
+    nbytes = psutil.virtual_memory().total
+    return round(nbytes / 1024**3, 2)
+
 def is_installed(
     module_name:str # name of the module that is being checked
     ):
     "Determines if a module is installed without importing it"
     return importlib.util.find_spec(module_name) is not None
 
-class ExtraDependencies:
-    sktime = is_installed("sktime")
-    tsfresh = is_installed("tsfresh")
-    pywt = is_installed("pywt")
+# class ExtraDependencies:
+#     sktime = is_installed("sktime")
+#     tsfresh = is_installed("tsfresh")
+#     pywt = is_installed("pywt")
 
 def is_lab():
     import re
-    import psutil
     return any(re.search('jupyter-lab', x) for x in psutil.Process().parent().cmdline())
 
 def is_colab():
@@ -280,8 +290,8 @@ def my_setup(*pkgs):
     except: 
         print(f'fastcore       : N/A')
     
-    if pkgs is not None: 
-        for pkg in listify(pkgs):
+    if pkgs: 
+        for pkg in pkgs:
             try: print(f'{pkg.__name__:15}: {pkg.__version__}')
             except: pass 
     try: 
@@ -292,9 +302,26 @@ def my_setup(*pkgs):
             print(f'device         : TPU')
         except:
             iscuda = torch.cuda.is_available()
-            print(f'n_cpus         : {cpus}')
-            print(f'device         : {device} ({torch.cuda.get_device_name(0)})' if iscuda else f'device         : {device}')
-    except: print(f'torch          : N/A')
+            if iscuda:
+                device_count = torch.cuda.device_count()
+                gpu_text = 'gpu' if device_count == 1 else 'gpus'
+                print(f'device         : {device_count} {gpu_text} ({[torch.cuda.get_device_name(i) for i in range(device_count)]})')
+            else:
+                print(f'device         : {device}')
+    except: pass
+    try:
+        print(f'cpu cores      : {cpus}')
+    except:
+        print(f'cpu cores      : N/A')
+    try:
+        print(f'RAM            : {get_ram_memory()} GB')
+    except:
+        print(f'RAM            : N/A')
+    try:
+        print(f'GPU memory     : {get_gpu_memory()} GB')
+    except:
+        print(f'GPU memory     : N/A')
+        
         
 computer_setup = my_setup
 
