@@ -7,6 +7,7 @@ from .TCN import *
 from .InceptionTime import *
 from .InceptionTimePlus import *
 from .MLP import *
+from .gMLP import *
 from .mWDN import *
 from .OmniScaleCNN import *
 from .ResCNN import *
@@ -16,6 +17,8 @@ from .RNN import *
 from .RNNPlus import *
 from .RNN_FCN import *
 from .RNN_FCNPlus import *
+from .ROCKET import *
+from .MINIROCKET import *
 from .ROCKET_Pytorch import *
 from .MINIROCKET_Pytorch import *
 from .MINIROCKETPlus_Pytorch import *
@@ -35,10 +38,4 @@ from .TabFusionTransformer import *
 from .TSPerceiver import *
 from .TSiTPlus import *
 from .MultiInputNet import *
-from .misc import *
-
-# Conditional import
-from ..imports import ExtraDependencies
-if ExtraDependencies.sktime:
-    from .ROCKET import *
-    from .MINIROCKET import *
\ No newline at end of file
+from .misc import *
\ No newline at end of file
